.. lda-over-time documentation master file, created by
   sphinx-quickstart on Sat Oct 29 18:27:43 2022.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to lda-over-time's documentation!
=========================================

.. toctree::
   :maxdepth: 8
   :caption: Contents:

   modules



Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
